@@ -7,35 +7,40 @@ import os
 import signal
 
 from context import pdb_attach, pdb_detach
+from skip import skip_windows
 
 
 def test_detach():
     """Test the debugger goes to the next line then detaches."""
     inp = io.StringIO("detach\n")
-    debugger = pdb_detach.PdbDetach(stdin=inp, stdout=open(os.devnull, "w"))
-    debugger.set_trace()
-    assert True  # If pdb quits this will never be reached.
+    with open(os.devnull, "w") as f:
+        debugger = pdb_detach.PdbDetach(stdin=inp, stdout=f)
+        debugger.set_trace()
+        assert True  # If pdb quits this will never be reached.
 
 
 def test_state_changes():
     """Test the state changes that happen in the debugger persist."""
     val = False
     inp = io.StringIO("val = True\ndetach\n")
-    debugger = pdb_detach.PdbDetach(stdin=inp, stdout=open(os.devnull, "w"))
-    debugger.set_trace()
-    assert val is True
+    with open(os.devnull, "w") as f:
+        debugger = pdb_detach.PdbDetach(stdin=inp, stdout=f)
+        debugger.set_trace()
+        assert val is True
 
 
 def test_correct_detach_line():
     """Test line after set_trace is not executed after the debugger detaches."""
     val = False
     inp = io.StringIO("n\nval = True\ndetach\n")
-    debugger = pdb_detach.PdbDetach(stdin=inp, stdout=open(os.devnull, "w"))
-    debugger.set_trace()
-    val = False
-    assert val is True
+    with open(os.devnull, "w") as f:
+        debugger = pdb_detach.PdbDetach(stdin=inp, stdout=f)
+        debugger.set_trace()
+        val = False
+        assert val is True
 
 
+@skip_windows
 def test_signal_set():
     """Test the signal handler is set and unset by listen and unlisten."""
     pdb_attach.listen(0)
@@ -44,6 +49,15 @@ def test_signal_set():
     assert not isinstance(signal.getsignal(signal.SIGUSR2), pdb_detach._Handler)
 
 
+@skip_windows
+def test_original_signal_restored():
+    """Test the original signal is restored by unlisten."""
+    pdb_attach.listen(0)
+    cur_sig = signal.getsignal(signal.SIGUSR2)
+    pdb_attach.unlisten()
+    assert cur_sig.original_handler is signal.getsignal(signal.SIGUSR2)
+
+
 def test_precmd_handler_runs():
     """Test attached precmd handler is executed.
 
@@ -58,7 +72,8 @@ def test_precmd_handler_runs():
         return line
 
     inp = io.StringIO("detach\n")
-    debugger = pdb_detach.PdbDetach(stdin=inp, stdout=open(os.devnull, "w"))
-    debugger.attach_precmd_handler(precmd)
-    debugger.set_trace()
-    assert val[0] is True
+    with open(os.devnull, "w") as f:
+        debugger = pdb_detach.PdbDetach(stdin=inp, stdout=f)
+        debugger.attach_precmd_handler(precmd)
+        debugger.set_trace()
+        assert val[0] is True
